@@ -1,4 +1,4 @@
-from typing import Type, Callable, TypeVar
+from typing import Callable, Type, TypeVar
 
 from ..tasks.storage import list_tasks
 
@@ -13,7 +13,7 @@ def task(name: str, **options) -> Callable[[Type[T]], Type[T]]:
         options['name'] = name
 
         async def task_handler(data):
-            instance = cls.makeit()
+            instance = cls()
             await instance.run(data)
 
         list_tasks.append({'name': name, 'handler': task_handler})
